@@ -1,3 +1,22 @@
+#   BAREOS - Backup Archiving REcovery Open Sourced
+#
+#   Copyright (C) 2018-2020 Bareos GmbH & Co. KG
+#
+#   This program is Free Software; you can redistribute it and/or
+#   modify it under the terms of version three of the GNU Affero General Public
+#   License as published by the Free Software Foundation and included
+#   in the file LICENSE.
+#
+#   This program is distributed in the hope that it will be useful, but
+#   WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+#   Affero General Public License for more details.
+#
+#   You should have received a copy of the GNU Affero General Public License
+#   along with this program; if not, write to the Free Software
+#   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+#   02110-1301, USA.
+
 """
 Low Level socket methods to communication with the bareos-director.
 """
@@ -49,10 +68,10 @@ class LowLevel(object):
     def argparser_get_bareos_parameter(args):
         """
         This method is usally used together with the method argparser_add_default_command_line_arguments.
-        
+
         @param args: Arguments retrieved by ArgumentParser.parse_args()
         @type args:  ArgParser.Namespace
-        
+
         @return: returns the relevant parameter from args to initialize a connection.
         @rtype: dict
         """
@@ -497,6 +516,8 @@ class LowLevel(object):
             except EOFError:
                 return False
             try:
+                if command == "exit" or command == "quit":
+                    return True
                 resultmsg = self.call(command)
                 self._show_result(resultmsg)
             except bareos.exceptions.JsonRpcErrorReceivedException as exp:
@@ -519,8 +540,8 @@ class LowLevel(object):
         sys.stdout.write(msg.decode("utf-8"))
         # add a linefeed, if there isn't one already
         if len(msg) >= 2:
-            if msg[-2] != ord(b'\n'):
-                sys.stdout.write(b'\n')
+            if msg[-2] != ord(b"\n"):
+                sys.stdout.write("\n")
 
     def __get_header(self, timeout=10):
         header = self.recv_bytes(4, timeout)
